.. role:: header_no_toc
  :class: class_header_no_toc

.. title:: Welcome to tree's documentation!

:tocdepth: 2

.. rubric:: :header_no_toc:`Welcome to tree's documentation!`

This is the Sphinx documentation for the Python product tree

Introduction
------------

* :doc:`What's new in tree? <CHANGELOG>`
* :doc:`Installation of python package <installation>`
* :doc:`Introduction to the Tree <intro>`
* :doc:`Tree environment configuration <config>`
* :doc:`Setting up the Tree in your local enviroment <tree_setup>`
* :doc:`Adding a new path into the Tree <paths>`

Reference
---------

.. toctree::
   :maxdepth: 1

   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
